@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: file.c,v 1.13 1999/06/03 14:21:07 wichert Exp $
+ *	$Id: file.c,v 1.16 1999/07/09 00:32:54 wichert Exp $
  */
 
 #include "defs.h"
@@ -66,7 +66,43 @@ struct stat {
 #    include <asm/stat.h>
 #    undef stat
 #  else
+#    undef dev_t
+#    undef ino_t
+#    undef mode_t
+#    undef nlink_t
+#    undef uid_t
+#    undef gid_t
+#    undef off_t
+#    undef loff_t
+
+#    define dev_t __kernel_dev_t
+#    define ino_t __kernel_ino_t
+#    define mode_t __kernel_mode_t
+#    define nlink_t __kernel_nlink_t
+#    define uid_t __kernel_uid_t
+#    define gid_t __kernel_gid_t
+#    define off_t __kernel_off_t
+#    define loff_t __kernel_loff_t
+
 #    include <asm/stat.h>
+
+#    undef dev_t
+#    undef ino_t
+#    undef mode_t
+#    undef nlink_t
+#    undef uid_t
+#    undef gid_t
+#    undef off_t
+#    undef loff_t
+
+#    define dev_t dev_t
+#    define ino_t ino_t
+#    define mode_t mode_t
+#    define nlink_t nlink_t
+#    define uid_t uid_t
+#    define gid_t gid_t
+#    define off_t off_t
+#    define loff_t loff_t
 #  endif
 #  define stat libc_stat
 #  include <sys/stat.h>
@@ -784,6 +820,61 @@ struct tcb *tcp;
 	return 0;
 }
 
+#ifdef HAVE_SYS_ACL_H
+
+#include <sys/acl.h>
+
+struct xlat aclcmds[] = {
+	{ SETACL,	"SETACL"	},
+	{ GETACL,	"GETACL"	},
+	{ GETACLCNT,	"GETACLCNT"	},
+	{ 0,		NULL		},
+};
+
+int
+sys_acl(tcp)
+struct tcb *tcp;
+{
+	if (entering(tcp)) {
+		printpath(tcp, tcp->u_arg[0]);
+		tprintf(", ");
+		printxval(aclcmds, tcp->u_arg[1], "???ACL???");
+		tprintf(", %ld", tcp->u_arg[2]);
+		/*
+		 * FIXME - dump out the list of aclent_t's pointed to
+		 * by "tcp->u_arg[3]" if it's not NULL.
+		 */
+		if (tcp->u_arg[3])
+			tprintf(", %#lx", tcp->u_arg[3]);
+		else
+			tprintf(", NULL");
+	}
+	return 0;
+}
+
+
+int
+sys_facl(tcp)
+struct tcb *tcp;
+{
+	if (entering(tcp)) {
+		tprintf("%ld, ", tcp->u_arg[0]);
+		printxval(aclcmds, tcp->u_arg[1], "???ACL???");
+		tprintf(", %ld", tcp->u_arg[2]);
+		/*
+		 * FIXME - dump out the list of aclent_t's pointed to
+		 * by "tcp->u_arg[3]" if it's not NULL.
+		 */
+		if (tcp->u_arg[3])
+			tprintf(", %#lx", tcp->u_arg[3]);
+		else
+			tprintf(", NULL");
+	}
+	return 0;
+}
+
+#endif /* HAVE_SYS_ACL_H */
+
 #endif /* SVR4 || LINUXSPARC */
 
 #ifdef linux
