@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: dummy.h,v 1.2 1999/04/16 00:21:26 wichert Exp $
+ *	$Id: dummy.h,v 1.4 1999/05/27 12:00:57 wichert Exp $
  */
 
 /* still unfinished */
@@ -43,7 +43,6 @@
 #define	sys_afs_syscall		printargs
 
 #define sys_fdatasync		printargs
-#define sys_sysctl		printargs
 #define sys_mlock		printargs
 #define sys_munlock		printargs
 #define sys_mlockall		printargs
@@ -56,7 +55,6 @@
 #define sys_sched_get_priority_max printargs
 #define sys_sched_get_priority_min printargs
 #define sys_sched_rr_get_interval printargs
-#define sys_mremap		printargs
 
 /* like another call */
 #define	sys_uselib		sys_chdir
