@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: mem.c,v 1.5 1999/05/09 00:29:58 wichert Exp $
+ *	$Id: mem.c,v 1.8 1999/06/22 15:28:30 wichert Exp $
  */
 
 #include "defs.h"
@@ -85,6 +85,33 @@ static struct xlat mmap_flags[] = {
 #ifdef MAP_NORESERVE
 	{ MAP_NORESERVE,"MAP_NORESERVE"	},
 #endif
+	/*
+	 * XXX - this was introduced in SunOS 4.x to distinguish between
+	 * the old pre-4.x "mmap()", which:
+	 *
+	 *	only let you map devices with an "mmap" routine (e.g.,
+	 *	frame buffers) in;
+	 *
+	 *	required you to specify the mapping address;
+	 *
+	 *	returned 0 on success and -1 on failure;
+	 *
+	 * memory and which, and the 4.x "mmap()" which:
+	 *
+	 *	can map plain files;
+	 *
+	 *	can be asked to pick where to map the file;
+	 *
+	 *	returns the address where it mapped the file on success
+	 *	and -1 on failure.
+	 *
+	 * It's not actually used in source code that calls "mmap()"; the
+	 * "mmap()" routine adds it for you.
+	 *
+	 * It'd be nice to come up with some way of eliminating it from
+	 * the flags, e.g. reporting calls *without* it as "old_mmap()"
+	 * and calls with it as "mmap()".
+	 */
 #ifdef _MAP_NEW
 	{ _MAP_NEW,	"_MAP_NEW"	},
 #endif
@@ -111,7 +138,7 @@ sys_mmap(tcp)
 struct tcb *tcp;
 {
 #ifdef LINUX
-#  if defined(ALPHA) || defined(sparc)
+#  if defined(ALPHA) || defined(sparc) || defined(POWERPC)
 	long *u_arg = tcp->u_arg;
 #  else /* !ALPHA */
 	long u_arg[6];
@@ -121,14 +148,17 @@ struct tcb *tcp;
 #endif /* !LINUX */
 
 	if (entering(tcp)) {
-#if defined(LINUX) && !defined(ALPHA) && !defined(__sparc__)
+#if defined(LINUX) && !defined(ALPHA) && !defined(sparc) && !defined(POWERPC)
 		if (umoven(tcp, tcp->u_arg[0], sizeof u_arg,
 				(char *) u_arg) == -1)
 			return 0;
-#endif /* LINUX && !ALPHA && !sparc */
+#endif /* LINUX && !ALPHA && !sparc && !POWERPC */
 
 		/* addr */
-		tprintf("%#lx, ", u_arg[0]);
+		if (!u_arg[0])
+			tprintf("NULL, ");
+		else
+			tprintf("%#lx, ", u_arg[0]);
 		/* len */
 		tprintf("%lu, ", u_arg[1]);
 		/* prot */
