@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: net.c,v 1.3 1999/04/06 01:39:04 nate Exp $
+ *	$Id: net.c,v 1.5 1999/05/11 15:06:44 wichert Exp $
  */
 
 #include "defs.h"
@@ -340,7 +340,7 @@ long addr;
 		tprintf("sin_port=htons(%u), sin_addr=inet_addr(\"%s\")}",
 			ntohs(sin->sin_port), inet_ntoa(sin->sin_addr));
 		break;
-#ifdef AF_IPX
+#if defined(AF_IPX) && defined(linux)
 	case AF_IPX:
 		if (umove(tcp, addr, &sipx)<0)
 			tprintf("{sipx_family=AF_IPX, ...}");
@@ -362,7 +362,7 @@ long addr;
 			tprintf("}");
 		}
 		break;
-#endif /* AF_IPX */
+#endif /* AF_IPX  && linux */
 	/* AF_AX25 AF_APPLETALK AF_NETROM AF_BRIDGE AF_AAL5
 	AF_X25 AF_INET6 AF_ROSE still need to be done */
 
@@ -384,9 +384,14 @@ long addr;
 {
 	struct msghdr msg;
 
-	umove(tcp, addr, &msg);
-	tprintf("{msg_name=%s, msg_namelen=%u, msg_iov=%#lx, msg_iovlen=%u, ",
-		(char *) msg.msg_name, msg.msg_namelen,
+	if (umove(tcp, addr, &msg) < 0) {
+		tprintf("%#lx", addr);
+		return;
+	}
+	tprintf("{msg_name=");
+	printstr(tcp, (long) msg.msg_name, msg.msg_namelen);
+	tprintf(", msg_namelen=%u, msg_iov=%#lx, msg_iovlen=%u, ",
+		msg.msg_namelen,
 		(unsigned long) msg.msg_iov, msg.msg_iovlen);
 #ifdef HAVE_MSG_CONTROL
 	tprintf("msg_control=%#lx, msg_controllen=%u, msg_flags=%#x}",
@@ -706,17 +711,17 @@ struct tcb *tcp;
 			break;
 #endif /* PF_IPX */
 		default:	
-			tprintf(", %lu", tcp->u_arg[2]);
+			tprintf("%lu", tcp->u_arg[2]);
 			break;
 		}
 	} else {
 		if (syserror(tcp)) {
-			tprintf("%#lx", tcp->u_arg[3]);
+			tprintf(", %#lx", tcp->u_arg[3]);
 			return 0;
 		}
 #ifdef LINUX
 		if (umoven(tcp, tcp->u_arg[3], sizeof fds, (char *) fds) < 0)
-			tprintf("[...]");
+			tprintf(", [...]");
 		else
 			tprintf(", [%u, %u]", fds[0], fds[1]);
 #endif /* LINUX */
