@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: process.c,v 1.8 1999/05/09 00:29:58 wichert Exp $
+ *	$Id: process.c,v 1.9 1999/06/11 13:18:40 wichert Exp $
  */
 
 #include "defs.h"
@@ -114,6 +114,15 @@ static struct xlat prctl_options[] = {
 #endif
 #if defined(PR_SET_PDEATHSIG)
 	{ PR_SET_PDEATHSIG,	"PR_SET_PDEATHSIG"	},
+#endif
+#ifdef PR_COREPID
+	{ PR_COREPID,		"PR_COREPID"		},
+#endif
+#ifdef PR_ATTACHADDRPERM
+	{ PR_ATTACHADDRPERM,	"PR_ATTACHADDRPERM"	},
+#endif
+#ifdef PR_PTHREADEXIT
+	{ PR_PTHREADEXIT,	"PR_PTHREADEXIT"	},
 #endif
 	{ 0,			NULL			},
 };
