@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscall.c,v 1.6 1999/06/03 14:21:07 wichert Exp $
+ *	$Id: syscall.c,v 1.9 1999/06/24 13:55:29 wichert Exp $
  */
 
 #include "defs.h"
@@ -37,13 +37,14 @@
 #include <sys/user.h>
 #include <sys/syscall.h>
 #include <sys/param.h>
-#if __GLIBC__ == 2 && __GLIBC_MINOR__ >= 1 && (defined(I386) || defined(M68K))
-# include <sys/reg.h>
-#endif
 
-#if defined LINUX && __GLIBC__ < 2
-#include <linux/ptrace.h>
-#endif /* LINUX */
+#if __GLIBC__ == 2 && ((defined(I386) && __GLIBC_MINOR__ >= 0) || (defined(M68K) && __GLIBC_MINOR__ >= 1))
+# include <sys/reg.h>
+#else
+# if defined LINUX
+#  include <linux/ptrace.h>
+# endif /* LINUX */
+#endif
 
 #ifndef SYS_ERRLIST_DECLARED
 extern int sys_nerr;
@@ -135,7 +136,8 @@ int nerrnos;
 int current_personality;
 
 int
-set_personality(int personality)
+set_personality(personality)
+int personality;
 {
 	switch (personality) {
 	case 0:
@@ -394,7 +396,7 @@ struct tcb *tcp;
 	}
 }
 
-enum subcall_style { shift_style, deref_style, mask_style };
+enum subcall_style { shift_style, deref_style, mask_style, door_style };
 
 #if !(defined(LINUX) && defined(ALPHA))
 
@@ -419,7 +421,8 @@ const int socket_map [] = {
 };
 
 void
-sparc_socket_decode (struct tcb *tcp)
+sparc_socket_decode (tcp)
+struct tcb *tcp;
 {
 	volatile long addr;
 	volatile int i, n;
@@ -480,6 +483,16 @@ enum subcall_style style;
 		if (sysent[tcp->scno].nargs != -1)
 			tcp->u_nargs = sysent[tcp->scno].nargs;
 		break;
+	case door_style:
+		/*
+		 * Oh, yuck.  The call code is the *sixth* argument.
+		 */
+		tcp->scno = subcall + tcp->u_arg[5];
+		if (sysent[tcp->scno].nargs != -1)
+			tcp->u_nargs = sysent[tcp->scno].nargs;
+		else
+			tcp->u_nargs--;
+		break;
 	}
 }
 #endif
@@ -1201,6 +1214,12 @@ struct tcb *tcp;
 			SYS_context_nsubcalls, shift_style);
 		break;
 #endif /* SYS_context_subcall */
+#ifdef SYS_door_subcall
+	case SYS_door:
+		decode_subcall(tcp, SYS_door_subcall,
+			SYS_door_nsubcalls, door_style);
+		break;
+#endif /* SYS_door_subcall */
 #endif /* SVR4 */
 #ifdef SUNOS4
 	case SYS_semsys:
