@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: system.c,v 1.4 1999/06/03 14:21:07 wichert Exp $
+ *	$Id: system.c,v 1.6 1999/07/03 18:53:05 nate Exp $
  */
 
 #include "defs.h"
@@ -45,19 +45,24 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
-#ifdef __NR_personality
+#include <sys/syscall.h>
+
+#ifdef SYS_personality
 /* Workaround for kernel namespace pollution. */
 #define _LINUX_PTRACE_H
+/* Yuck yuck yuck.  We can't include linux/ptrace.h, but personality.h
+   makes a declaration with struct pt_regs, which is defined there. */
+struct pt_regs;
 #define sys_personality kernel_sys_personality
 #include <linux/personality.h>
 #undef sys_personality
-#endif /* __NR_personality */
+#endif /* SYS_personality */
 
-#ifdef __NR_capget
+#ifdef SYS_capget
 #include <linux/capability.h>
 #endif
 
-#ifdef __NR_cacheflush
+#ifdef SYS_cacheflush
 #include <asm/cachectl.h>
 #endif
 
@@ -708,7 +713,9 @@ struct tcb *tcp;
 
 static struct xlat syssgi_options[] = {
 	{ SGI_SYSID,		"SGI_SYSID"		},
+#ifdef SGI_RDUBLK
 	{ SGI_RDUBLK,		"SGI_RDUBLK"		},
+#endif
 	{ SGI_TUNE,		"SGI_TUNE"		},
 	{ SGI_IDBG,		"SGI_IDBG"		},
 	{ SGI_INVENT,		"SGI_INVENT"		},
@@ -765,6 +772,27 @@ static struct xlat syssgi_options[] = {
 	{ SGI_PLANGMOUNT,	"SGI_PLANGMOUNT"	},
 	{ SGI_GETPSOACL,	"SGI_GETPSOACL"		},
 	{ SGI_SETPSOACL,	"SGI_SETPSOACL"		},
+#ifdef SGI_EAG_GET_ATTR
+	{ SGI_EAG_GET_ATTR,	"SGI_EAG_GET_ATTR"	},
+#endif
+#ifdef SGI_EAG_SET_ATTR
+	{ SGI_EAG_SET_ATTR,	"SGI_EAG_SET_ATTR"	},
+#endif
+#ifdef SGI_EAG_GET_PROCATTR
+	{ SGI_EAG_GET_PROCATTR,	"SGI_EAG_GET_PROCATTR"	},
+#endif
+#ifdef SGI_EAG_SET_PROCATTR
+	{ SGI_EAG_SET_PROCATTR,	"SGI_EAG_SET_PROCATTR"	},
+#endif
+#ifdef SGI_FREVOKE
+	{ SGI_FREVOKE,		"SGI_FREVOKE"		},
+#endif
+#ifdef SGI_SBE_GET_INFO
+	{ SGI_SBE_GET_INFO,	"SGI_SBE_GET_INFO"	},
+#endif
+#ifdef SGI_SBE_CLR_INFO
+	{ SGI_SBE_CLR_INFO,	"SGI_SBE_CLR_INFO"	},
+#endif
 	{ SGI_RMI_FIXECC,	"SGI_RMI_FIXECC"	},
 	{ SGI_R4K_CERRS,	"SGI_R4K_CERRS"		},
 	{ SGI_GET_EVCONF,	"SGI_GET_EVCONF"	},
@@ -774,10 +802,274 @@ static struct xlat syssgi_options[] = {
 	{ SGI_SYMTAB,		"SGI_SYMTAB"		},
 #ifdef SGI_SET_FPDEBUG
 	{ SGI_SET_FPDEBUG,	"SGI_SET_FPDEBUG"	},
+#endif
+#ifdef SGI_SET_FP_PRECISE
+	{ SGI_SET_FP_PRECISE,	"SGI_SET_FP_PRECISE"	},
 #endif
 	{ SGI_TOSSTSAVE,	"SGI_TOSSTSAVE"		},
 	{ SGI_FDHI,		"SGI_FDHI"		},
+#ifdef SGI_SET_CONFIG_SMM
+	{ SGI_SET_CONFIG_SMM,	"SGI_SET_CONFIG_SMM"	},
+#endif
+#ifdef SGI_SET_FP_PRESERVE
+	{ SGI_SET_FP_PRESERVE,	"SGI_SET_FP_PRESERVE"	},
+#endif
 	{ SGI_MINRSS,		"SGI_MINRSS"		},
+#ifdef SGI_GRIO
+	{ SGI_GRIO,		"SGI_GRIO"		},
+#endif
+#ifdef SGI_XLV_SET_TAB
+	{ SGI_XLV_SET_TAB,	"SGI_XLV_SET_TAB"	},
+#endif
+#ifdef SGI_XLV_GET_TAB
+	{ SGI_XLV_GET_TAB,	"SGI_XLV_GET_TAB"	},
+#endif
+#ifdef SGI_GET_FP_PRECISE
+	{ SGI_GET_FP_PRECISE,	"SGI_GET_FP_PRECISE"	},
+#endif
+#ifdef SGI_GET_CONFIG_SMM	
+	{ SGI_GET_CONFIG_SMM,	"SGI_GET_CONFIG_SMM"	},
+#endif
+#ifdef SGI_FP_IMPRECISE_SUPP	
+	{ SGI_FP_IMPRECISE_SUPP,"SGI_FP_IMPRECISE_SUPP"	},
+#endif
+#ifdef SGI_CONFIG_NSMM_SUPP	
+	{ SGI_CONFIG_NSMM_SUPP,	"SGI_CONFIG_NSMM_SUPP"	},
+#endif
+#ifdef SGI_RT_TSTAMP_CREATE    
+	{ SGI_RT_TSTAMP_CREATE,	"SGI_RT_TSTAMP_CREATE"	},
+#endif
+#ifdef SGI_RT_TSTAMP_DELETE    
+	{ SGI_RT_TSTAMP_DELETE,	"SGI_RT_TSTAMP_DELETE"	},
+#endif
+#ifdef SGI_RT_TSTAMP_START     
+	{ SGI_RT_TSTAMP_START,	"SGI_RT_TSTAMP_START"	},
+#endif
+#ifdef SGI_RT_TSTAMP_STOP      
+	{ SGI_RT_TSTAMP_STOP,	"SGI_RT_TSTAMP_STOP"	},
+#endif
+#ifdef SGI_RT_TSTAMP_ADDR      
+	{ SGI_RT_TSTAMP_ADDR,	"SGI_RT_TSTAMP_ADDR"	},
+#endif
+#ifdef SGI_RT_TSTAMP_MASK      
+	{ SGI_RT_TSTAMP_MASK,	"SGI_RT_TSTAMP_MASK"	},
+#endif
+#ifdef SGI_RT_TSTAMP_EOB_MODE  
+	{ SGI_RT_TSTAMP_EOB_MODE,"SGI_RT_TSTAMP_EOB_MODE"},
+#endif
+#ifdef SGI_USE_FP_BCOPY	
+	{ SGI_USE_FP_BCOPY,	"SGI_USE_FP_BCOPY"	},
+#endif
+#ifdef SGI_GET_UST		
+	{ SGI_GET_UST,		"SGI_GET_UST"		},
+#endif
+#ifdef SGI_SPECULATIVE_EXEC	
+	{ SGI_SPECULATIVE_EXEC,	"SGI_SPECULATIVE_EXEC"	},
+#endif
+#ifdef SGI_XLV_NEXT_RQST	
+	{ SGI_XLV_NEXT_RQST,	"SGI_XLV_NEXT_RQST"	},
+#endif
+#ifdef SGI_XLV_ATTR_CURSOR	
+	{ SGI_XLV_ATTR_CURSOR,	"SGI_XLV_ATTR_CURSOR"	},
+#endif
+#ifdef SGI_XLV_ATTR_GET	
+	{ SGI_XLV_ATTR_GET,	"SGI_XLV_ATTR_GET"	},
+#endif
+#ifdef SGI_XLV_ATTR_SET	
+	{ SGI_XLV_ATTR_SET,	"SGI_XLV_ATTR_SET"	},
+#endif
+#ifdef SGI_BTOOLSIZE
+	{ SGI_BTOOLSIZE,	"SGI_BTOOLSIZE"		},
+#endif
+#ifdef SGI_BTOOLGET		
+	{ SGI_BTOOLGET,		"SGI_BTOOLGET"		},
+#endif
+#ifdef SGI_BTOOLREINIT		
+	{ SGI_BTOOLREINIT,	"SGI_BTOOLREINIT"	},
+#endif
+#ifdef SGI_CREATE_UUID		
+	{ SGI_CREATE_UUID,	"SGI_CREATE_UUID"	},
+#endif
+#ifdef SGI_NOFPE		
+	{ SGI_NOFPE,		"SGI_NOFPE"		},
+#endif
+#ifdef SGI_OLD_SOFTFP		
+	{ SGI_OLD_SOFTFP,	"SGI_OLD_SOFTFP"	},
+#endif
+#ifdef SGI_FS_INUMBERS		
+	{ SGI_FS_INUMBERS,	"SGI_FS_INUMBERS"	},
+#endif
+#ifdef SGI_FS_BULKSTAT		
+	{ SGI_FS_BULKSTAT,	"SGI_FS_BULKSTAT"	},
+#endif
+#ifdef SGI_RT_TSTAMP_WAIT	
+	{ SGI_RT_TSTAMP_WAIT,	"SGI_RT_TSTAMP_WAIT"	},
+#endif
+#ifdef SGI_RT_TSTAMP_UPDATE    
+	{ SGI_RT_TSTAMP_UPDATE,	"SGI_RT_TSTAMP_UPDATE"	},
+#endif
+#ifdef SGI_PATH_TO_HANDLE	
+	{ SGI_PATH_TO_HANDLE,	"SGI_PATH_TO_HANDLE"	},
+#endif
+#ifdef SGI_PATH_TO_FSHANDLE	
+	{ SGI_PATH_TO_FSHANDLE,	"SGI_PATH_TO_FSHANDLE"	},
+#endif
+#ifdef SGI_FD_TO_HANDLE	
+	{ SGI_FD_TO_HANDLE,	"SGI_FD_TO_HANDLE"	},
+#endif
+#ifdef SGI_OPEN_BY_HANDLE	
+	{ SGI_OPEN_BY_HANDLE,	"SGI_OPEN_BY_HANDLE"	},
+#endif
+#ifdef SGI_READLINK_BY_HANDLE	
+	{ SGI_READLINK_BY_HANDLE,"SGI_READLINK_BY_HANDLE"},
+#endif
+#ifdef SGI_READ_DANGID		
+	{ SGI_READ_DANGID,	"SGI_READ_DANGID"	},
+#endif
+#ifdef SGI_CONST		
+	{ SGI_CONST,		"SGI_CONST"		},
+#endif
+#ifdef SGI_XFS_FSOPERATIONS	
+	{ SGI_XFS_FSOPERATIONS,	"SGI_XFS_FSOPERATIONS"	},
+#endif
+#ifdef SGI_SETASH		
+	{ SGI_SETASH,		"SGI_SETASH"		},
+#endif
+#ifdef SGI_GETASH		
+	{ SGI_GETASH,		"SGI_GETASH"		},
+#endif
+#ifdef SGI_SETPRID		
+	{ SGI_SETPRID,		"SGI_SETPRID"		},
+#endif
+#ifdef SGI_GETPRID		
+	{ SGI_GETPRID,		"SGI_GETPRID"		},
+#endif
+#ifdef SGI_SETSPINFO		
+	{ SGI_SETSPINFO,	"SGI_SETSPINFO"		},
+#endif
+#ifdef SGI_GETSPINFO		
+	{ SGI_GETSPINFO,	"SGI_GETSPINFO"		},
+#endif
+#ifdef SGI_SHAREII		
+	{ SGI_SHAREII,		"SGI_SHAREII"		},
+#endif
+#ifdef SGI_NEWARRAYSESS	
+	{ SGI_NEWARRAYSESS,	"SGI_NEWARRAYSESS"	},
+#endif
+#ifdef SGI_GETDFLTPRID		
+	{ SGI_GETDFLTPRID,	"SGI_GETDFLTPRID"	},
+#endif
+#ifdef SGI_SET_DISMISSED_EXC_CNT 
+	{ SGI_SET_DISMISSED_EXC_CNT,"SGI_SET_DISMISSED_EXC_CNT"	},
+#endif
+#ifdef SGI_GET_DISMISSED_EXC_CNT 
+	{ SGI_GET_DISMISSED_EXC_CNT,"SGI_GET_DISMISSED_EXC_CNT"	},
+#endif
+#ifdef SGI_CYCLECNTR_SIZE	
+	{ SGI_CYCLECNTR_SIZE,	"SGI_CYCLECNTR_SIZE"	},
+#endif
+#ifdef SGI_QUERY_FASTTIMER	
+	{ SGI_QUERY_FASTTIMER,	"SGI_QUERY_FASTTIMER"	},
+#endif
+#ifdef SGI_PIDSINASH		
+	{ SGI_PIDSINASH,	"SGI_PIDSINASH"		},
+#endif
+#ifdef SGI_ULI			
+	{ SGI_ULI,		"SGI_ULI"		},
+#endif
+#ifdef SGI_LPG_SHMGET          
+	{ SGI_LPG_SHMGET,	"SGI_LPG_SHMGET"	},
+#endif
+#ifdef SGI_LPG_MAP             
+	{ SGI_LPG_MAP,		"SGI_LPG_MAP"		},
+#endif
+#ifdef SGI_CACHEFS_SYS		
+	{ SGI_CACHEFS_SYS,	"SGI_CACHEFS_SYS"	},
+#endif
+#ifdef SGI_NFSNOTIFY		
+	{ SGI_NFSNOTIFY,	"SGI_NFSNOTIFY"		},
+#endif
+#ifdef SGI_LOCKDSYS		
+	{ SGI_LOCKDSYS,		"SGI_LOCKDSYS"		},
+#endif
+#ifdef SGI_EVENTCTR            
+	{ SGI_EVENTCTR,		"SGI_EVENTCTR"		},
+#endif
+#ifdef SGI_GETPRUSAGE          
+	{ SGI_GETPRUSAGE,	"SGI_GETPRUSAGE"	},
+#endif
+#ifdef SGI_PROCMASK_LOCATION	
+	{ SGI_PROCMASK_LOCATION,"SGI_PROCMASK_LOCATION"	},
+#endif
+#ifdef SGI_UNUSED		
+	{ SGI_UNUSED,		"SGI_UNUSED"		},
+#endif
+#ifdef SGI_CKPT_SYS		
+	{ SGI_CKPT_SYS,		"SGI_CKPT_SYS"		},
+#endif
+#ifdef SGI_CKPT_SYS		
+	{ SGI_CKPT_SYS,		"SGI_CKPT_SYS"		},
+#endif
+#ifdef SGI_GETGRPPID		
+	{ SGI_GETGRPPID,	"SGI_GETGRPPID"		},
+#endif
+#ifdef SGI_GETSESPID		
+	{ SGI_GETSESPID,	"SGI_GETSESPID"		},
+#endif
+#ifdef SGI_ENUMASHS		
+	{ SGI_ENUMASHS,		"SGI_ENUMASHS"		},
+#endif
+#ifdef SGI_SETASMACHID		
+	{ SGI_SETASMACHID,	"SGI_SETASMACHID"	},
+#endif
+#ifdef SGI_GETASMACHID		
+	{ SGI_GETASMACHID,	"SGI_GETASMACHID"	},
+#endif
+#ifdef SGI_GETARSESS		
+	{ SGI_GETARSESS,	"SGI_GETARSESS"		},
+#endif
+#ifdef SGI_JOINARRAYSESS	
+	{ SGI_JOINARRAYSESS,	"SGI_JOINARRAYSESS"	},
+#endif
+#ifdef SGI_SPROC_KILL		
+	{ SGI_SPROC_KILL,	"SGI_SPROC_KILL"	},
+#endif
+#ifdef SGI_DBA_CONFIG		
+	{ SGI_DBA_CONFIG,	"SGI_DBA_CONFIG"	},
+#endif
+#ifdef SGI_RELEASE_NAME	
+	{ SGI_RELEASE_NAME,	"SGI_RELEASE_NAME"	},
+#endif
+#ifdef SGI_SYNCH_CACHE_HANDLER 
+	{ SGI_SYNCH_CACHE_HANDLER,"SGI_SYNCH_CACHE_HANDLER"},
+#endif
+#ifdef SGI_SWASH_INIT		
+	{ SGI_SWASH_INIT,	"SGI_SWASH_INIT"	},
+#endif
+#ifdef SGI_NUMA_MIGR_PAGE	
+	{ SGI_NUMA_MIGR_PAGE,	"SGI_NUMA_MIGR_PAGE"	},
+#endif
+#ifdef SGI_NUMA_MIGR_PAGE_ALT	
+	{ SGI_NUMA_MIGR_PAGE_ALT,"SGI_NUMA_MIGR_PAGE_ALT"},
+#endif
+#ifdef SGI_KAIO_USERINIT	
+	{ SGI_KAIO_USERINIT,	"SGI_KAIO_USERINIT"	},
+#endif
+#ifdef SGI_KAIO_READ		
+	{ SGI_KAIO_READ,	"SGI_KAIO_READ"		},
+#endif
+#ifdef SGI_KAIO_WRITE		
+	{ SGI_KAIO_WRITE,	"SGI_KAIO_WRITE"	},
+#endif
+#ifdef SGI_KAIO_SUSPEND	
+	{ SGI_KAIO_SUSPEND,	"SGI_KAIO_SUSPEND"	},
+#endif
+#ifdef SGI_KAIO_STATS		
+	{ SGI_KAIO_STATS,	"SGI_KAIO_STATS"	},
+#endif
+#ifdef SGI_INITIAL_PT_SPROC	
+	{ SGI_INITIAL_PT_SPROC,	"SGI_INITIAL_PT_SPROC"	},
+#endif
 	{ 0,			NULL			},
 };
 
@@ -829,7 +1121,12 @@ static struct xlat nfs_flags[] = {
 	{ NFSMNT_TIMEO,		"NFSMNT_TIMEO"		},
 	{ NFSMNT_RETRANS,	"NFSMNT_RETRANS"	},
 	{ NFSMNT_HOSTNAME,	"NFSMNT_HOSTNAME"	},
+#ifdef NFSMNT_NOINT	/* IRIX 6 */
+	{ NFSMNT_NOINT,		"NFSMNT_NOINT"		},
+#endif
+#ifdef NFSMNT_INT	/* IRIX 5 */
 	{ NFSMNT_INT,		"NFSMNT_INT"		},
+#endif
 	{ NFSMNT_NOAC,		"NFSMNT_NOAC"		},
 	{ NFSMNT_ACREGMIN,	"NFSMNT_ACREGMIN"	},
 	{ NFSMNT_ACREGMAX,	"NFSMNT_ACREGMAX"	},
@@ -840,6 +1137,12 @@ static struct xlat nfs_flags[] = {
 	{ NFSMNT_LOOPBACK,	"NFSMNT_LOOPBACK"	},
 	{ NFSMNT_BASETYPE,	"NFSMNT_BASETYPE"	},
 	{ NFSMNT_NAMEMAX,	"NFSMNT_NAMEMAX"	},
+#ifdef NFSMNT_SHORTUID	/* IRIX 6 */
+	{ NFSMNT_SHORTUID,	"NFSMNT_SHORTUID"	},
+#endif
+#ifdef NFSMNT_ASYNCNLM	/* IRIX 6 */
+	{ NFSMNT_ASYNCNLM,	"NFSMNT_ASYNCNLM"	},
+#endif
 	{ 0,			NULL			},
 };
 
@@ -903,7 +1206,7 @@ struct tcb *tcp;
 
 #endif /* SVR4 */
 
-#ifdef __NR_capget
+#ifdef SYS_capget
 int
 sys_capget(tcp)
 struct tcb *tcp;
